"""
Provides Operators working on single tensors.
"""

from .tensor import np_one_hot, torch_one_hot
